==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/nl_nl/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Uitgaand';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Inkomend';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'De naam van de parameter mag niet langer zijn dan 255 tekens.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'De parameter van het veld kan niet leeg zijn.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'De naam van het veld mag niet langer zijn dan 255 tekens.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'De naam van het veld mag niet leeg zijn.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Selecteer een geldige methode.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Selecteer een geldig type.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'De opgegeven gebeurtenis bestaat niet.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'De callback mag niet langer zijn dan 255 tekens.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Voer een geldige callback in.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Er bestaat al een webhook van dit type met deze callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Het opgegeven bedrijf bestaat niet.';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/nl_nl/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'GET';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Uitgaand';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Inkomend';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'De naam van de parameter mag niet langer zijn dan 255 tekens.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'De parameter van het veld kan niet leeg zijn.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'De naam van het veld mag niet langer zijn dan 255 tekens.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'De naam van het veld mag niet leeg zijn.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Selecteer een geldige methode.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Selecteer een geldig type.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'De opgegeven gebeurtenis bestaat niet.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'De callback mag niet langer zijn dan 255 tekens.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Voer een geldige callback in.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Er bestaat al een webhook van dit type met deze callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Het opgegeven bedrijf bestaat niet.';
$lang['WebhooksWebhooks.getMethods.put_json'] = 'PUT JSON';
$lang['WebhooksWebhooks.getMethods.post_json'] = 'POST JSON';
$lang['WebhooksWebhooks.getMethods.put'] = 'PUT';
$lang['WebhooksWebhooks.!error.events[].exists'] = 'De opgegeven gebeurtenis bestaat niet.';
